@@ -1,22 +1,35 @@
-
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package MetaPOD::Result;
-BEGIN {
-  $MetaPOD::Result::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $MetaPOD::Result::VERSION = '0.3.5';
-}
-
+$MetaPOD::Result::VERSION = '0.3.6';
 # ABSTRACT: Compiled aggregate result object for MetaPOD
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
-use Moo;
+
+
+
+
+
+
+
+
+
+
+
+
+use Moo qw( has );
 use List::AllUtils qw( uniq );
 
 
+
+
+
+
+
 has namespace => (
   is       => ro            =>,
   required => 0,
@@ -54,12 +67,22 @@ has interface => (
 );
 
 
+
+
+
+
+
 sub inherits {
   my $self = shift;
   return @{ $self->_inherits };
 }
 
 
+
+
+
+
+
 sub set_inherits {
   my ( $self, @inherits ) = @_;
   $self->_set_inherits( [ uniq @inherits ] );
@@ -67,6 +90,11 @@ sub set_inherits {
 }
 
 
+
+
+
+
+
 sub add_inherits {
   my ( $self, @items ) = @_;
   $self->_set_inherits( [ uniq @{ $self->_inherits }, @items ] );
@@ -74,12 +102,22 @@ sub add_inherits {
 }
 
 
+
+
+
+
+
 sub does {
   my $self = shift;
   return @{ $self->_does };
 }
 
 
+
+
+
+
+
 sub set_does {
   my ( $self, @does ) = @_;
   $self->_set_does( [ uniq @does ] );
@@ -87,6 +125,11 @@ sub set_does {
 }
 
 
+
+
+
+
+
 sub add_does {
   my ( $self, @items ) = @_;
   $self->_set_does( [ uniq @{ $self->_does }, @items ] );
@@ -94,12 +137,22 @@ sub add_does {
 }
 
 
+
+
+
+
+
 sub interface {
   my $self = shift;
   return @{ $self->_interface };
 }
 
 
+
+
+
+
+
 sub set_interface {
   my ( $self, @interfaces ) = @_;
   $self->_set_interface( [ uniq @interfaces ] );
@@ -107,6 +160,11 @@ sub set_interface {
 }
 
 
+
+
+
+
+
 sub add_interface {
   my ( $self, @items ) = @_;
   $self->_set_interface( [ uniq @{ $self->_interface }, @items ] );
@@ -127,7 +185,7 @@ MetaPOD::Result - Compiled aggregate result object for MetaPOD
 
 =head1 VERSION
 
-version 0.3.5
+version 0.3.6
 
 =head1 METHODS
 
@@ -188,7 +246,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
